@@ -3,53 +3,53 @@ from datetime import timedelta
 
 class dtutil(object):
     @classmethod
-    def getXdayBefore(cls, n: int, dt=None)->str:
+    def getXdayBefore(cls, n: int, dt=None, fmt='%Y-%m-%d')->str:
         if dt is None:
             dt = datetime.datetime.now()
         if n > 0:
             dt -= datetime.timedelta(days=n)
         else:
             dt += datetime.timedelta(days=-n)
-        return dt.strftime('%Y-%m-%d')
+        return dt.strftime(fmt)
 
     @classmethod
-    def getMonday(cls, dt=None)->str:
+    def getMonday(cls, dt=None, fmt='%Y-%m-%d')->str:
         if dt is None:
             dt = datetime.date.today() 
         dt += datetime.timedelta(days=-dt.weekday())
-        return dt.strftime('%Y-%m-%d')
+        return dt.strftime(fmt)
 
     @classmethod
-    def getNextMonday(cls, dt=None)->str:
+    def getNextMonday(cls, dt=None, fmt='%Y-%m-%d')->str:
         if dt is None:
             dt = datetime.date.today()
         dt += datetime.timedelta(days=7-dt.weekday())
-        return dt.strftime('%Y-%m-%d')
+        return dt.strftime(fmt)
 
     @classmethod
-    def getSunday(cls, dt=None)->str:
+    def getSunday(cls, dt=None, fmt='%Y-%m-%d')->str:
         if dt is None:
             dt = datetime.date.today()
         dt += datetime.timedelta(days=-dt.weekday()+6)
-        return dt.strftime('%Y-%m-%d')
+        return dt.strftime(fmt)
 
     @classmethod
-    def getStartOfMonth(cls, dt=None)->str:
+    def getStartOfMonth(cls, dt=None, fmt='%Y-%m-%d')->str:
         if dt is None:
             dt = datetime.date.today()
         dt = datetime.datetime(dt.year, dt.month, 1)
-        return dt.strftime('%Y-%m-%d')
+        return dt.strftime(fmt)
 
     @classmethod
-    def getStartOfNextMonth(cls, dt=None)->str:
+    def getStartOfNextMonth(cls, dt=None, fmt='%Y-%m-%d')->str:
         if dt is None:
             dt = datetime.date.today()
         dt = datetime.datetime(dt.year, dt.month, 1) + datetime.timedelta(days=calendar.monthrange(dt.year, dt.month)[1])
-        return dt.strftime('%Y-%m-%d')
+        return dt.strftime(fmt)
 
     @classmethod
-    def getEndOfMonth(cls, dt=None)->str:
+    def getEndOfMonth(cls, dt=None, fmt='%Y-%m-%d')->str:
         if dt is None:
             dt = datetime.date.today()
         dt = datetime.datetime(dt.year, dt.month, calendar.monthrange(dt.year, dt.month)[1])
-        return dt.strftime('%Y-%m-%d')
\ No newline at end of file
+        return dt.strftime(fmt)
\ No newline at end of file
